@@ -4,10 +4,9 @@ usage: sl dns [<command>] [<args>...] [options]
 Manage DNS
 
 The available commands are:
-  search  Look for a resource record by exact name
   edit    Update resource records (bulk/single)
   create  Create zone
-  list    List zones
+  list    List zones or a zone's records
   remove  Remove resource records
   add     Add resource record
   print   Print zone in BIND format
@@ -16,8 +15,9 @@ The available commands are:
 # :copyright: (c) 2013, SoftLayer Technologies, Inc. All rights reserved.
 # :license: BSD, see LICENSE for more details.
 
-from SoftLayer.CLI import CLIRunnable, no_going_back, Table, CLIAbort
-from SoftLayer.DNS import DNSManager, DNSZoneNotFound
+from SoftLayer.CLI import (
+    CLIRunnable, no_going_back, Table, CLIAbort, resolve_id)
+from SoftLayer import DNSManager, DNSZoneNotFound
 
 
 class DumpZone(CLIRunnable):
@@ -34,8 +34,9 @@ Arguments:
     @staticmethod
     def execute(client, args):
         manager = DNSManager(client)
+        zone_id = resolve_id(manager.resolve_ids, args['<zone>'], name='zone')
         try:
-            return manager.dump_zone(manager.get_zone(args['<zone>'])['id'])
+            return manager.dump_zone(zone_id)
         except DNSZoneNotFound:
             raise CLIAbort("No zone found matching: %s" % args['<zone>'])
 
@@ -72,21 +73,73 @@ Arguments:
     @staticmethod
     def execute(client, args):
         manager = DNSManager(client)
+        zone_id = resolve_id(manager.resolve_ids, args['<zone>'], name='zone')
+
         if args['--really'] or no_going_back(args['<zone>']):
-            manager.delete_zone(args['<zone>'])
+            manager.delete_zone(zone_id)
         raise CLIAbort("Aborted.")
 
 
 class ListZones(CLIRunnable):
     """
-usage: sl dns list [options]
+usage: sl dns list [<zone>] [options]
 
-List zones
+List zones and optionally, records
+
+Filters:
+  --type=TYPE    Record type, such as A or CNAME
+  --data=DATA    Record data, such as an IP address
+  --record=HOST  Host record, such as www
+  --ttl=TTL      TTL value in seconds, such as 86400
 """
     action = 'list'
 
+    @classmethod
+    def execute(cls, client, args):
+        if args['<zone>']:
+            return cls.list_zone(client, args['<zone>'], args)
+
+        return cls.list_all_zones(client)
+
     @staticmethod
-    def execute(client, args):
+    def list_zone(client, zone, args):
+        manager = DNSManager(client)
+        t = Table([
+            "record",
+            "type",
+            "ttl",
+            "value",
+        ])
+
+        t.align['ttl'] = 'l'
+        t.align['record'] = 'r'
+        t.align['value'] = 'l'
+
+        zone_id = resolve_id(manager.resolve_ids, args['<zone>'], name='zone')
+
+        try:
+            records = manager.get_records(
+                zone_id,
+                type=args.get('--type'),
+                host=args.get('--record'),
+                ttl=args.get('--ttl'),
+                data=args.get('--data'),
+            )
+        except DNSZoneNotFound:
+            raise CLIAbort("No zone found matching: %s" % args['<zone>'])
+
+        for rr in records:
+            t.add_row([
+                rr['host'],
+                rr['type'].upper(),
+                rr['ttl'],
+                rr['data']
+            ])
+
+        return t
+
+    @staticmethod
+    def list_all_zones(client):
         manager = DNSManager(client)
         zones = manager.list_zones()
         t = Table([
@@ -130,12 +183,11 @@ Options:
     @staticmethod
     def execute(client, args):
         manager = DNSManager(client)
-        try:
-            zone = manager.get_zone(args['<zone>'])['id']
-        except DNSZoneNotFound:
-            raise CLIAbort("No zone found matching: %s" % args['<zone>'])
+
+        zone_id = resolve_id(manager.resolve_ids, args['<zone>'], name='zone')
+
         manager.create_record(
-            zone,
+            zone_id,
             args['<record>'],
             args['<type>'],
             args['<data>'],
@@ -163,9 +215,11 @@ Options:
     @staticmethod
     def execute(client, args):
         manager = DNSManager(client)
+        zone_id = resolve_id(manager.resolve_ids, args['<zone>'], name='zone')
+
         try:
             results = manager.search_record(
-                args['<zone>'],
+                zone_id,
                 args['<record>'])
         except DNSZoneNotFound:
             raise CLIAbort("No zone found matching: %s" % args['<zone>'])
@@ -178,39 +232,6 @@ Options:
             manager.edit_record(r)
 
 
-class RecordSearch(CLIRunnable):
-    """
-usage: sl dns search <zone> <record> [options]
-
-Look for a resource record by exact name
-
-Arguments:
-  <zone>    Zone name (softlayer.com)
-  <record>  Resource record (www)
-"""
-    action = 'search'
-
-    @staticmethod
-    def execute(client, args):
-        manager = DNSManager(client)
-        results = []
-        try:
-            results = manager.search_record(
-                args['<zone>'],
-                args['<record>'])
-        except DNSZoneNotFound:
-            raise CLIAbort("No zone found matching: %s" % args['<zone>'])
-
-        t = Table(['id', 'type', 'ttl', 'data'])
-
-        t.align['ttl'] = 'c'
-
-        for r in results:
-            t.add_row([r['id'], r['type'], r['ttl'], r['data']])
-
-        return t
-
-
 class RecordRemove(CLIRunnable):
     """
 usage: sl dns remove <zone> <record> [--id=ID] [options]
@@ -230,13 +251,14 @@ Options:
     @staticmethod
     def execute(client, args):
         manager = DNSManager(client)
+        zone_id = resolve_id(manager.resolve_ids, args['<zone>'], name='zone')
 
         if args['--id']:
             records = [{'id': args['--id']}]
         else:
             try:
                 records = manager.search_record(
-                    args['<zone>'],
+                    zone_id,
                     args['<record>'])
             except DNSZoneNotFound:
                 raise CLIAbort("No zone found matching: %s" % args['<zone>'])
