@@ -16,6 +16,7 @@ from mock import MagicMock, patch
 import SoftLayer
 import SoftLayer.CLI as cli
 from SoftLayer.CLI.helpers import CLIAbort
+from SoftLayer.CLI.environment import Environment, InvalidModule
 
 
 def module_fixture():
@@ -39,18 +40,32 @@ Options:
         return "test"
 
 
+class EnvironmentFixture(Environment):
+    plugins = {'cci': {'list': submodule_fixture}}
+    aliases = {
+        'meta': 'metadata',
+        'my': 'metadata',
+    }
+    config = {}
+
+    def load_module(self, *args, **kwargs):
+        return module_fixture
+
+    def plugin_list(self, *args, **kwargs):
+        return self.plugins.keys()
+
+
 class CommandLineTests(unittest.TestCase):
     def setUp(self):
-        self.env = MagicMock()
-        self.env.plugin_list.return_value = ['cci']
-        self.env.plugins = {'cci': {'list': submodule_fixture}}
-        self.env.load_module.return_value = module_fixture
+        self.env = EnvironmentFixture()
+        self.env.get_module_name = MagicMock()
 
     def test_normal_path(self):
         self.env.get_module_name.return_value = 'cci'
         self.assertRaises(
             SystemExit, cli.core.main,
-            args=['cci', 'list', '--config=path/to/config'], env=self.env)
+            args=['cci', 'list', '--config=path/to/config'],
+            env=self.env)
         self.assertRaises(
             SystemExit, cli.core.main,
             args=['cci', 'nope', '--config=path/to/config'], env=self.env)
@@ -58,6 +73,17 @@ class CommandLineTests(unittest.TestCase):
             SystemExit, cli.core.main,
             args=['cci', 'list', '--format=totallynotvalid'], env=self.env)
 
+    @patch('logging.getLogger')
+    @patch('logging.StreamHandler')
+    def test_with_debug(self, stream_handler, logger):
+        self.env.get_module_name.return_value = 'cci'
+        self.assertRaises(
+            SystemExit, cli.core.main,
+            args=['cci', 'list', '--debug=3'],
+            env=self.env)
+        logger().setLevel.assert_called_with(10)
+        logger().addHandler.assert_called_with(stream_handler())
+
     def test_invalid_module(self):
         self.env.get_module_name.return_value = 'nope'
         self.assertRaises(
@@ -80,11 +106,21 @@ class CommandLineTests(unittest.TestCase):
         self.assertRaises(
             SystemExit, cli.core.main, args=['cci', 'list'], env=self.env)
 
+    def test_invalid_module_error(self):
+        self.env.get_module_name.side_effect = InvalidModule('cci')
+        self.assertRaises(
+            SystemExit, cli.core.main, args=['cci', 'list'], env=self.env)
+
     def test_softlayer_error(self):
         self.env.get_module_name.side_effect = SoftLayer.SoftLayerError
         self.assertRaises(
             SystemExit, cli.core.main, args=['cci', 'list'], env=self.env)
 
+    def test_system_exit_error(self):
+        self.env.get_module_name.side_effect = SystemExit
+        self.assertRaises(
+            SystemExit, cli.core.main, args=['cci', 'list'], env=self.env)
+
     def test_value_key_errors(self):
         self.env.get_module_name.side_effect = ValueError
         self.assertRaises(
@@ -94,60 +130,79 @@ class CommandLineTests(unittest.TestCase):
         self.assertRaises(
             KeyError, cli.core.main, args=['cci', 'list'], env=self.env)
 
+    @patch('traceback.format_exc')
+    def test_uncaught_error(self, m):
+        # Exceptions not caught should just Exit
+        errors = [TypeError, RuntimeError, NameError, OSError, SystemError]
+        for err in errors:
+            m.reset_mock()
+            m.return_value = 'testing'
+            self.env.get_module_name.side_effect = err
+            self.assertRaises(
+                SystemExit, cli.core.main, args=['cci', 'list'], env=self.env)
+            m.assert_called_once_with()
+
+
+class TestCommandParser(unittest.TestCase):
+    def setUp(self):
+        self.env = EnvironmentFixture()
+        self.parser = cli.core.CommandParser(self.env)
 
-class TestParseMainArgs(unittest.TestCase):
     def test_main(self,):
-        args = cli.core.parse_main_args(
+        args = self.parser.parse_main_args(
             args=['cci', 'list'])
 
         self.assertEqual(args['help'], False)
-        self.assertEqual(args['<command>'], 'cci')
+        self.assertEqual(args['<module>'], 'cci')
         self.assertEqual(args['<args>'], ['list'])
 
     def test_primary_help(self):
-        args = cli.core.parse_main_args(args=[])
+        args = self.parser.parse_main_args(args=[])
         self.assertEqual({
             '--help': False,
             '-h': False,
             '<args>': [],
+            '<module>': None,
             '<command>': None,
             'help': False,
         }, args)
 
-        args = cli.core.parse_main_args(args=['help'])
+        args = self.parser.parse_main_args(args=['help'])
         self.assertEqual({
             '--help': False,
             '-h': False,
             '<args>': [],
-            '<command>': 'help',
+            '<module>': 'help',
+            '<command>': None,
             'help': False,
         }, args)
 
-        args = cli.core.parse_main_args(args=['help', 'module'])
+        args = self.parser.parse_main_args(args=['help', 'module'])
         self.assertEqual({
             '--help': False,
             '-h': False,
             '<args>': ['module'],
-            '<command>': 'help',
+            '<module>': 'help',
+            '<command>': None,
             'help': False,
         }, args)
 
         self.assertRaises(
-            SystemExit, cli.core.parse_main_args, args=['--help'])
+            SystemExit, self.parser.parse_main_args, args=['--help'])
 
-
-class TestParseSubmoduleArgs(unittest.TestCase):
     @patch('sys.stdout.isatty', return_value=True)
     def test_tty(self, tty):
         self.assertRaises(
-            SystemExit, cli.core.parse_submodule_args, submodule_fixture, [])
+            SystemExit, self.parser.parse_command_args, 'cci', 'list', [])
 
     def test_confirm(self):
-        submodule = MagicMock()
-        submodule.options = ['confirm']
-        submodule.__doc__ = 'usage: sl cci list [options]'
+        command = MagicMock()
+        command.options = ['confirm']
+        command.__doc__ = 'usage: sl cci list [options]'
+        self.env.get_command = MagicMock()
+        self.env.get_command.return_value = command
         self.assertRaises(
-            SystemExit, cli.core.parse_submodule_args, submodule, [''])
+            SystemExit, self.parser.parse_command_args, 'cci', 'list', [])
 
 
 class TestFormatOutput(unittest.TestCase):
