@@ -9,10 +9,9 @@ import sys
 try:
     import unittest2 as unittest
 except ImportError:
-    import unittest # NOQA
+    import unittest  # NOQA
 from mock import patch
 
-
 import SoftLayer.CLI as cli
 
 if sys.version_info >= (3,):
@@ -119,6 +118,19 @@ class FormattedItemTests(unittest.TestCase):
 
         self.assertRaises(ValueError, cli.mb_to_gb, '1024string')
 
+    def test_gb(self):
+        item = cli.gb(2)
+        self.assertEqual(2048, item.original)
+        self.assertEqual('2G', item.formatted)
+
+        item = cli.gb('2')
+        self.assertEqual(2048, item.original)
+        self.assertEqual('2G', item.formatted)
+
+        item = cli.gb('2.0')
+        self.assertEqual(2048, item.original)
+        self.assertEqual('2G', item.formatted)
+
     def test_blank(self):
         item = cli.helpers.blank()
         self.assertEqual('NULL', item.original)
@@ -144,3 +156,22 @@ class CLIRunnableTypeTests(unittest.TestCase):
         self.assertEqual(
             cli.environment.CLIRunnableType.env.plugins,
             {'helper_tests': {'test': TestCommand}})
+
+
+class ResolveIdTests(unittest.TestCase):
+
+    def test_resolve_id_one(self):
+        resolver = lambda r: [12345]
+        id = cli.helpers.resolve_id(resolver, 'test')
+
+        self.assertEqual(id, 12345)
+
+    def test_resolve_id_none(self):
+        resolver = lambda r: []
+        self.assertRaises(
+            cli.helpers.CLIAbort, cli.helpers.resolve_id, resolver, 'test')
+
+    def test_resolve_id_multiple(self):
+        resolver = lambda r: [12345, 54321]
+        self.assertRaises(
+            cli.helpers.CLIAbort, cli.helpers.resolve_id, resolver, 'test')
